class PressureCharge {
	constructor(game, x, y, r, direction){
		this.game = game;
		
		// Rendering
		this.texture = game.textures.projectiles;
		this.map = game.atlas.projectiles.pressureBolt;
		
		// Scale
		this.scale = 1;
		this.originalWidth = this.scale * 5 * 0.4 * 1.5;
		this.originalHeight = this.scale * 11;
		
		this.width = this.originalWidth;
		this.height = 0;
		this.maxHeight = this.originalHeight * 2
		
		// Physics
		this.x = x;
		this.y = y;
		this.r = r;
		this.direction = direction;
		this.radius = 0;
		
		this.collision = {
			with: [ Alien ],
			width: 0,
			height: 0,
			radius: 0,
			offsetX: 0,
			offsetY: 0,
			hitRadius: 0,
			isDud: true,
			piercing: false
		};
		
		// Bolt
		this.maxLife = 5;
		this.life = this.maxLife;
		this.isAlive = true;
	}
	
	
	update(delta){
		var speed = 84/2,
			angle = 45,
			rate = 0.8;
		
		var that = this;
		
		this.collision.offsetY = this.height/2;
		
		for(var i=0; i<3; i++){
			doMovement();
			doCollision(this);
		}
		
		// Player Collision
		var player = this.game.scene.player,
			targetX = this.x,
			targetY = this.y;
		
		targetX += this.height/2 *  Math.sin(this.r/180*Math.PI);
		targetY += this.height/2 * -Math.cos(this.r/180*Math.PI);
		
		if(this.isAlive && 3 > Math.hypot(targetX - player.x, targetY - player.y)){
			player.damage(1);
			this.isAlive = false;
		}
		
		// Create a particle
		if(this.game.canShowParticle(2)){
			// this.game.scene.addParticle(new PressureBoltTrail(this.game, this.texture, this.map, this.x, this.y, this.r, this.width, this.height, this.maxHeight, this.isAlive));
		}
		
		function doMovement(){
			// Grow the height
			if(that.isAlive){
				var offsetX = delta * speed * Math.sin(that.r/180*Math.PI),
				 	offsetY = delta * speed * -Math.cos(that.r/180*Math.PI);
				
				if(that.height!==that.maxHeight){
					that.height += delta * speed;
					that.height = Math.min(that.height, that.maxHeight);
					that.x += offsetX/2;
					that.y += offsetY/2;
				}
				
				else{
					that.x += offsetX;
					that.y += offsetY;
				}
				
				that.boltTimer += delta;
			}
			
			// Shrink the height
			else{
				that.x += delta * speed/2 * Math.sin(that.r/180*Math.PI);
				that.y += delta * speed/2 * -Math.cos(that.r/180*Math.PI);
				
				that.height -= delta * speed;
				if(that.height<=0) return that.life = 0;
			}
		}
		
		return this.life -= delta;
	}
	
	
	draw(context, textures, atlas){
		var texture = this.texture,
			map = this.map;
		
		context.save();
		context.translate(this.x, this.y);
		context.rotate(this.r/180*Math.PI);
		
		context.drawImage(
			texture,
			
			// Sprite Crop Location
			map[0],
			map[1] + (this.isAlive ? 0 : map[3] * (1 - this.height/this.maxHeight)),
			map[2],
			map[3] * this.height/this.maxHeight,
			
			// Screen Space Location
			-this.width/2,
			-this.height/2,
			this.width,
			this.height
		);

		context.restore();
	}
}
